==> phpgroupware-jp-0.9.16.003-pre1.tar.bz2: phpgroupware/phpgwapi/inc/footer.inc.php <==
<?php
	/**
	* Closes out interface and db connections
	* @author Dan Kuykendall <seek3r@phpgroupware.org>
	* @author Joseph Engo <jengo@phpgroupware.org>
	* @copyright Copyright (C) 2000-2004 Free Software Foundation, Inc. http://www.fsf.org/
	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
	* @package phpgwapi
	* @subpackage utilities
	* @version $Id: footer.inc.php,v 1.1.1.2 2004/04/06 23:11:29 kazuyan Exp $
	*/

	$d1 = strtolower(substr(PHPGW_APP_INC,0,3));
	if($d1 == 'htt' || $d1 == 'ftp')
	{
		echo "Failed attempt to break in via an old Security Hole!<br>\n";
		exit;
	} unset($d1);

	/**************************************************************************\
	* Include the apps footer files if it exists                               *
	\**************************************************************************/
	if (PHPGW_APP_INC != PHPGW_API_INC &&	// this prevents an endless inclusion on the homepage 
		                                	// (some apps set currentapp in hook_home => it's not releyable)
		(file_exists (PHPGW_APP_INC . '/footer.inc.php') || isset($GLOBALS['phpgw_info']['menuaction'])) &&
		$GLOBALS['phpgw_info']['flags']['currentapp'] != 'home' &&
		$GLOBALS['phpgw_info']['flags']['currentapp'] != 'login' &&
		$GLOBALS['phpgw_info']['flags']['currentapp'] != 'logout' &&
		!@$GLOBALS['phpgw_info']['flags']['noappfooter'])
	{
		if ($GLOBALS['phpgw_info']['menuaction'])
		{
			list($app,$class,$method) = explode('.',$GLOBALS['phpgw_info']['menuaction']);
			if (is_array($GLOBALS[$class]->public_functions) && $GLOBALS[$class]->public_functions['footer'])
			{
//				eval("\$GLOBALS[$class]->footer();");
				$GLOBALS[$class]->footer();
			}
			elseif(file_exists(PHPGW_APP_INC.'/footer.inc.php'))
			{
				include(PHPGW_APP_INC . '/footer.inc.php');
			}
		}
		elseif(file_exists(PHPGW_APP_INC.'/footer.inc.php'))
		{
			include(PHPGW_APP_INC . '/footer.inc.php');
		}
	}
	if(function_exists('parse_navbar_end'))
	{
		parse_navbar_end();
	}
	if (DEBUG_TIMER)
	{
		$GLOBALS['debug_timer_stop'] = perfgetmicrotime();
		echo 'Page loaded in ' . ($GLOBALS['debug_timer_stop'] - $GLOBALS['debug_timer_start']) . ' seconds.';
	}
?>
</BODY>
</HTML>

==> phpgroupware-jp-0.9.16.012-pre1.tar.bz2: phpgroupware/phpgwapi/inc/footer.inc.php <==
<?php
	/**
	* Closes out interface and db connections
	* @author Dan Kuykendall <seek3r@phpgroupware.org>
	* @author Joseph Engo <jengo@phpgroupware.org>
	* @copyright Copyright (C) 2000-2004 Free Software Foundation, Inc. http://www.fsf.org/
	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
	* @package phpgwapi
	* @subpackage utilities
	* @version $Id: footer.inc.php,v 1.1.1.4 2007/09/08 19:20:27 kazuyan Exp $
	*/

	$d1 = strtolower(substr(PHPGW_APP_INC,0,3));
	if($d1 == 'htt' || $d1 == 'ftp')
	{
		echo "Failed attempt to break in via an old Security Hole!<br />\n";
		exit;
	} unset($d1);

	/**************************************************************************\
	* Include the apps footer files if it exists                               *
	\**************************************************************************/
	if ( PHPGW_APP_INC != ''
		&& PHPGW_APP_INC != PHPGW_API_INC // this prevents an endless inclusion on the homepage (some apps set currentapp in hook_home => it's not reliable)
		&& (file_exists (PHPGW_APP_INC . '/footer.inc.php') || isset($GLOBALS['phpgw_info']['menuaction']))
		&& $GLOBALS['phpgw_info']['flags']['currentapp'] != 'home'
		&& $GLOBALS['phpgw_info']['flags']['currentapp'] != 'login'
		&& $GLOBALS['phpgw_info']['flags']['currentapp'] != 'logout' 
		&& ( !isset($GLOBALS['phpgw_info']['flags']['noappfooter']) || $GLOBALS['phpgw_info']['flags']['noappfooter']) )
	{
		if ($GLOBALS['phpgw_info']['menuaction'])
		{
			list($app,$class,$method) = explode('.',$GLOBALS['phpgw_info']['menuaction']);
			if (is_array($GLOBALS[$class]->public_functions) && $GLOBALS[$class]->public_functions['footer'])
			{
//				eval("\$GLOBALS[$class]->footer();");
				$GLOBALS[$class]->footer();
			}
			elseif(file_exists(PHPGW_APP_INC.'/footer.inc.php'))
			{
				include(PHPGW_APP_INC . '/footer.inc.php');
			}
		}
		elseif(file_exists(PHPGW_APP_INC.'/footer.inc.php'))
		{
			include(PHPGW_APP_INC . '/footer.inc.php');
		}
	}
	if(function_exists('parse_navbar_end'))
	{
		parse_navbar_end();
	}
	if (DEBUG_TIMER)
	{
		$GLOBALS['debug_timer_stop'] = perfgetmicrotime();
		echo 'Page loaded in ' . ($GLOBALS['debug_timer_stop'] - $GLOBALS['debug_timer_start']) . ' seconds.';
	}
?>
</BODY>
</HTML>
